@@ -1,10 +1,10 @@
 package App::Prove::State::Result;
 
 use strict;
-use warnings;
 use Carp 'croak';
 
 use App::Prove::State::Result::Test;
+use vars qw($VERSION);
 
 use constant STATE_VERSION => 1;
 
@@ -14,11 +14,11 @@ App::Prove::State::Result - Individual test suite results.
 
 =head1 VERSION
 
-Version 3.51_01
+Version 3.15
 
 =cut
 
-our $VERSION = '3.51_01';
+$VERSION = '3.15';
 
 =head1 DESCRIPTION
 
@@ -29,7 +29,7 @@ single test suite run.
 =head1 SYNOPSIS
 
     # Re-run failed tests
-    $ prove --state=failed,save -rbv
+    $ prove --state=fail,save -rbv
 
 =cut
 
@@ -223,7 +223,7 @@ sub raw {
     my %raw  = %$self;
 
     my %tests;
-    for my $test ( $self->tests ) {
+    foreach my $test ( $self->tests ) {
         $tests{ $test->name } = $test->raw;
     }
     $raw{tests} = \%tests;
