@@ -1,48 +1,35 @@
 package TAP::Formatter::Base;
 
 use strict;
-use warnings;
-use base 'TAP::Base';
+use TAP::Base ();
 use POSIX qw(strftime);
 
+use vars qw($VERSION @ISA);
+
 my $MAX_ERRORS = 5;
 my %VALIDATION_FOR;
 
 BEGIN {
+    @ISA = qw(TAP::Base);
+
     %VALIDATION_FOR = (
         directives => sub { shift; shift },
         verbosity  => sub { shift; shift },
-        normalize  => sub { shift; shift },
         timer      => sub { shift; shift },
         failures   => sub { shift; shift },
-        comments   => sub { shift; shift },
         errors     => sub { shift; shift },
         color      => sub { shift; shift },
         jobs       => sub { shift; shift },
         show_count => sub { shift; shift },
         stdout     => sub {
             my ( $self, $ref ) = @_;
-
             $self->_croak("option 'stdout' needs a filehandle")
-              unless $self->_is_filehandle($ref);
-
+              unless ( ref $ref || '' ) eq 'GLOB'
+              or eval { $ref->can('print') };
             return $ref;
         },
     );
 
-    sub _is_filehandle {
-        my ( $self, $ref ) = @_;
-
-        return 0 if !defined $ref;
-
-        return 1 if ref $ref eq 'GLOB';    # lexical filehandle
-        return 1 if !ref $ref && ref \$ref eq 'GLOB'; # bare glob like *STDOUT
-
-        return 1 if eval { $ref->can('print') };
-
-        return 0;
-    }
-
     my @getter_setters = qw(
       _longest
       _printed_summary_header
@@ -54,15 +41,15 @@ BEGIN {
 
 =head1 NAME
 
-TAP::Formatter::Base - Base class for harness output delegates
+TAP::Formatter::Console - Harness output delegate for default console output
 
 =head1 VERSION
 
-Version 3.51_01
+Version 3.15
 
 =cut
 
-our $VERSION = '3.51_01';
+$VERSION = '3.15';
 
 =head1 DESCRIPTION
 
@@ -145,11 +132,7 @@ Append run time for each test to output. Uses L<Time::HiRes> if available.
 
 =item * C<failures>
 
-Show test failures (this is a no-op if C<verbose> is selected).
-
-=item * C<comments>
-
-Show test comments (this is a no-op if C<verbose> is selected).
+Only show test failures (this is a no-op if C<verbose> is selected).
 
 =item * C<quiet>
 
@@ -174,7 +157,7 @@ true:
 =item * C<directives>
 
 If set to a true value, only test results with directives will be displayed.
-This overrides other settings such as C<verbose>, C<failures>, or C<comments>.
+This overrides other settings such as C<verbose> or C<failures>.
 
 =item * C<stdout>
 
@@ -217,7 +200,7 @@ sub prepare {
 
     my $longest = 0;
 
-    for my $test (@tests) {
+    foreach my $test (@tests) {
         $longest = length $test if length $test > $longest;
     }
 
@@ -259,24 +242,17 @@ sub open_test {
     die "Unimplemented.";
 }
 
-sub _output_success {
-    my ( $self, $msg ) = @_;
-    $self->_output($msg);
-}
-
 =head3 C<summary>
 
   $harness->summary( $aggregate );
 
-C<summary> prints the summary report after all tests are run. The first
-argument is an aggregate to summarise. An optional second argument may
-be set to a true value to indicate that the summary is being output as a
-result of an interrupted test run.
+C<summary> prints the summary report after all tests are run.  The argument is
+an aggregate.
 
 =cut
 
 sub summary {
-    my ( $self, $aggregate, $interrupted ) = @_;
+    my ( $self, $aggregate ) = @_;
 
     return if $self->silent;
 
@@ -292,21 +268,18 @@ sub summary {
         $self->_output( $self->_format_now(), "\n" );
     }
 
-    $self->_failure_output("Test run interrupted!\n")
-      if $interrupted;
-
     # TODO: Check this condition still works when all subtests pass but
     # the exit status is nonzero
 
     if ( $aggregate->all_passed ) {
-        $self->_output_success("All tests successful.\n");
+        $self->_output("All tests successful.\n");
     }
 
     # ~TODO option where $aggregate->skipped generates reports
     if ( $total != $passed or $aggregate->has_problems ) {
         $self->_output("\nTest Summary Report");
         $self->_output("\n-------------------\n");
-        for my $test (@$tests) {
+        foreach my $test (@$tests) {
             $self->_printed_summary_header(0);
             my ($parser) = $aggregate->parsers($test);
             $self->_output_summary_failure(
@@ -346,7 +319,7 @@ sub summary {
                     sprintf "  Parse errors: %s\n",
                     shift @errors
                 );
-                for my $error (@errors) {
+                foreach my $error (@errors) {
                     my $spaces = ' ' x 16;
                     $self->_failure_output("$spaces$error\n");
                 }
@@ -386,40 +359,17 @@ sub _summary_test_header {
     my $spaces = ' ' x ( $self->_longest - length $test );
     $spaces = ' ' unless $spaces;
     my $output = $self->_get_output_method($parser);
-    my $wait   = $parser->wait;
-
-    if (defined $wait) {
-        my $signum = $wait & 0x7f;
-
-        my $description;
-
-        if ($signum) {
-            require Config;
-            my @names = split ' ', $Config::Config{'sig_name'};
-            $description = "Signal: $names[$signum]";
-
-            my $dumped = $wait & 0x80;
-            $description .= ', dumped core' if $dumped;
-        }
-        elsif ($wait != 0) {
-            $description = sprintf 'exited %d', ($wait >> 8);
-        }
-
-        $wait .= " ($description)" if $wait != 0;
-    }
-    else {
-        $wait = '(none)';
-    }
-
     $self->$output(
-        sprintf "$test$spaces(Wstat: %s Tests: %d Failed: %d)\n",
-        $wait, $parser->tests_run, scalar $parser->failed
+        sprintf "$test$spaces(Wstat: %d Tests: %d Failed: %d)\n",
+        $parser->wait, $parser->tests_run, scalar $parser->failed
     );
     $self->_printed_summary_header(1);
 }
 
 sub _output {
-    print { shift->stdout } @_;
+    my $self = shift;
+
+    print { $self->stdout } @_;
 }
 
 sub _failure_output {
@@ -461,7 +411,7 @@ sub _range {
     @numbers = sort { $a <=> $b } @numbers;
     my ( $min, @range );
 
-    for my $i ( 0 .. $#numbers ) {
+    foreach my $i ( 0 .. $#numbers ) {
         my $num  = $numbers[$i];
         my $next = $numbers[ $i + 1 ];
         if ( defined $next && $next == $num + 1 ) {
