@@ -1,8 +1,11 @@
 package TAP::Formatter::File::Session;
 
 use strict;
-use warnings;
-use base 'TAP::Formatter::Session';
+use TAP::Formatter::Session;
+
+use vars qw($VERSION @ISA);
+
+@ISA = qw(TAP::Formatter::Session);
 
 =head1 NAME
 
@@ -10,11 +13,11 @@ TAP::Formatter::File::Session - Harness output delegate for file output
 
 =head1 VERSION
 
-Version 3.51_01
+Version 3.15
 
 =cut
 
-our $VERSION = '3.51_01';
+$VERSION = '3.15';
 
 =head1 DESCRIPTION
 
@@ -49,13 +52,12 @@ sub result {
     }
 
     if (!$formatter->quiet
-        && (   $formatter->verbose
+        && (   ( $formatter->verbose && !$formatter->failures )
             || ( $result->is_test && $formatter->failures && !$result->is_ok )
-            || ( $formatter->comments   && $result->is_comment )
             || ( $result->has_directive && $formatter->directives ) )
       )
     {
-        $self->{results} .= $self->_format_for_output($result) . "\n";
+        $self->{results} .= $result->as_string . "\n";
     }
 }
 
@@ -85,10 +87,22 @@ sub close_test {
         $self->_output_test_failure($parser);
     }
     else {
-        my $time_report = $self->time_report( $formatter, $parser );
-        $formatter->_output(
-            $pretty . ( $self->{results} ? "\n" . $self->{results} : "" ) );
-        $formatter->_output_success( $self->_make_ok_line($time_report) );
+        my $time_report = '';
+        if ( $formatter->timer ) {
+            my $start_time = $parser->start_time;
+            my $end_time   = $parser->end_time;
+            if ( defined $start_time and defined $end_time ) {
+                my $elapsed = $end_time - $start_time;
+                $time_report
+                  = $self->time_is_hires
+                  ? sprintf( ' %8d ms', $elapsed * 1000 )
+                  : sprintf( ' %8s s', $elapsed || '<1' );
+            }
+        }
+
+        $formatter->_output( $pretty
+              . ( $self->{results} ? "\n" . $self->{results} : "" )
+              . "ok$time_report\n" );
     }
 }
 
