@@ -1,9 +1,11 @@
 package TAP::Formatter::Session;
 
 use strict;
-use warnings;
+use TAP::Base;
 
-use base 'TAP::Base';
+use vars qw($VERSION @ISA);
+
+@ISA = qw(TAP::Base);
 
 my @ACCESSOR;
 
@@ -23,11 +25,11 @@ TAP::Formatter::Session - Abstract base class for harness output delegate
 
 =head1 VERSION
 
-Version 3.51_01
+Version 3.15
 
 =cut
 
-our $VERSION = '3.51_01';
+$VERSION = '3.15';
 
 =head1 METHODS
 
@@ -99,11 +101,6 @@ Called to close a test session.
 Called by C<close_test> to clear the line showing test progress, or the parallel
 test ruler, prior to printing the final test result.
 
-=head3 C<time_report>
-
-Return a formatted string about the elapsed (wall-clock) time
-and about the consumed CPU time.
-
 =cut
 
 sub header { }
@@ -116,15 +113,7 @@ sub clear_for_close { }
 
 sub _should_show_count {
     my $self = shift;
-    return
-         !$self->formatter->verbose
-      && -t $self->formatter->stdout
-      && !$ENV{HARNESS_NOTTY};
-}
-
-sub _format_for_output {
-    my ( $self, $result ) = @_;
-    return $self->formatter->normalize ? $result->as_string : $result->raw;
+    return !$self->formatter->verbose && -t $self->formatter->stdout;
 }
 
 sub _output_test_failure {
@@ -183,38 +172,4 @@ sub _output_test_failure {
     $formatter->_output("\n");
 }
 
-sub _make_ok_line {
-    my ( $self, $suffix ) = @_;
-    return "ok$suffix\n";
-}
-
-sub time_report {
-    my ( $self, $formatter, $parser ) = @_;
-
-    my @time_report;
-    if ( $formatter->timer ) {
-        my $start_time = $parser->start_time;
-        my $end_time   = $parser->end_time;
-        if ( defined $start_time and defined $end_time ) {
-            my $elapsed = $end_time - $start_time;
-            push @time_report,
-              $self->time_is_hires
-                ? sprintf( ' %8d ms', $elapsed * 1000 )
-                : sprintf( ' %8s s', $elapsed || '<1' );
-        }
-        my $start_times = $parser->start_times();
-        my $end_times   = $parser->end_times();
-        my $usr  = $end_times->[0] - $start_times->[0];
-        my $sys  = $end_times->[1] - $start_times->[1];
-        my $cusr = $end_times->[2] - $start_times->[2];
-        my $csys = $end_times->[3] - $start_times->[3];
-        push @time_report,
-          sprintf('(%5.2f usr %5.2f sys + %5.2f cusr %5.2f csys = %5.2f CPU)',
-                  $usr, $sys, $cusr, $csys,
-                  $usr + $sys + $cusr + $csys);
-    }
-
-    return "@time_report";
-}
-
 1;
